pub enum SignWith {
SignWithKeychain(SignKeychain),
SignWithLegacyKeychain(SignLegacyKeychain),
SignWithLedger(SignLedger),
SignWithPlaintextPrivateKey(SignPrivateKey),
SignWithAccessKeyFile(SignAccessKeyFile),
SignWithSeedPhrase(SignSeedPhrase),
SignLater(Display),
}Expand description
Select a tool for signing the transaction:
Variants
SignWithKeychain(SignKeychain)
Sign the transaction with a key saved in keychain
SignWithLegacyKeychain(SignLegacyKeychain)
Sign the transaction with a key saved in legacy keychain (compatible with the old unc CLI)
SignWithLedger(SignLedger)
Sign the transaction with Ledger Nano device
SignWithPlaintextPrivateKey(SignPrivateKey)
Sign the transaction with a plaintext private key
SignWithAccessKeyFile(SignAccessKeyFile)
Sign the transaction using the account access key file (access-key-file.json)
SignWithSeedPhrase(SignSeedPhrase)
Sign the transaction using the seed phrase
SignLater(Display)
Prepare unsigned transaction to sign it later
Implementations
Sourceimpl SignWith
impl SignWith
pub fn choose_variant( context: TransactionContext, ) -> ResultFromCli<<Self as ToCli>::CliVariant, <Self as FromCli>::FromCliError>
pub fn try_parse() -> Result<CliSignWith, Error>
pub fn parse() -> CliSignWith
pub fn try_parse_from(s: &str) -> Result<CliSignWith, Error>